==> nocc-1.9.5.txz: usr/local/www/nocc/lang/ast.php <==
<?php
/**
 * Language configuration file for NOCC
 *
 * Copyright 2001 Nicolas Chalanset <nicocha@free.fr>
 * Copyright 2001 Olivier Cahagne <cahagn_o@epita.fr>
 *
 * This file is part of NOCC. NOCC is free software under the terms of the
 * GNU General Public License. You should have received a copy of the license
 * along with NOCC.  If not, see <http://www.gnu.org/licenses/>.
 *
 * @package    NOCC
 * @subpackage Translations
 * @license    http://www.gnu.org/licenses/ GNU General Public License
 * @version    SVN: $Id: $
 */
/** Asturian (asturianu)
 * 
 * See the qqq 'language' for message documentation incl. usage of parameters
 * To improve a translation please visit http://translatewiki.net
 *
 * @ingroup Language
 * @file
 *
 * @author Xuacu
 */

$default_date_format = '%d-%m-%Y';
$no_locale_date_format = '%d-%m-%Y';
$default_time_format = '%I:%M %p';
$err_user_empty = 'El campu usuariu ta baleru';
$err_passwd_empty = 'El campu contraseña ta baleru';
$alt_delete = 'Desaniciar los mensaxes esbillaos';
$alt_delete_one = 'Desaniciar el mensaxe';
$alt_new_msg = 'Mensaxes nuevos';
$alt_reply = 'Contestar al autor';
$alt_reply_all = 'Contestar a toos';
$alt_forward = 'Reunviar';
$alt_next = 'Siguiente';
$alt_prev = 'Anterior';
$title_next_page = 'Páxina siguiente';
$title_prev_page = 'Páxina anterior';
$title_next_msg = 'Siguiente mensaxe';
$title_prev_msg = 'Mensaxe anterior';
$html_theme_label = 'Tema:';
$html_welcome = 'Bienveníu a %1$s';
$html_login = 'Aniciar sesión';
$html_user_label = 'Usuariu:';
$html_passwd_label = 'Contraseña:';
$html_submit = 'Unviar';
$html_help = 'Ayuda';
$html_server_label = 'Sirvidor:';
$html_wrong = 'L\'usuariu o la contraseña son incorreutos';
$html_retry = 'Reintentar';
$html_remember = 'Recordame';
$html_lang_label = 'Llingua:';
$html_msgperpage_label = 'Mensaxes por páxina:';
$html_preferences = 'Preferencies';
$html_full_name_label = 'Nome completu:';
$html_email_address_label = 'Direición de corréu electrónicu:';
$html_bccself = 'Poneme na CCT';
$html_hide_addresses = 'Tapecer les direiciones';
$html_outlook_quoting = 'Citar al estilu Outlook';
$html_reply_to = 'Responder a';
$html_reply_to_label = 'Responder a:';
$html_use_signature = 'Usar robla';
$html_signature = 'Robla';
$html_signature_label = 'Robla:';
$html_reply_leadin_label = 'Prefixu de respuesta:';
$html_prefs_updated = 'Preferencies anovaes';
$html_manage_folders_link = 'Xestionar carpetes IMAP';
$html_manage_filters_link = 'Xestionar filtros de corréu';
$html_use_graphical_smilies = 'Usar emoticonos gráficos';
$html_sent_folder_label = 'Copiar los correos unviaos a una carpeta dedicada:';
$html_trash_folder_label = 'Mover los correos desaniciaos a una carpeta dedicada:';
$html_colored_quotes = 'Cites en colores';
$html_display_struct = 'Amosar testu estructuráu';
$html_send_html_mail = 'Unviar el corréu en formatu HTML';
$html_folders = 'Carpetes';
$html_folders_create_failed = '¡Nun pudo crease la carpeta!';
$html_folders_sub_failed = '¡Nun pudisti suscribite a la carpeta!';
$html_folders_unsub_failed = '¡Nun pudisti de-suscribite de la carpeta!';
$html_folders_rename_failed = '¡Nun pudo cambiase\'l nome de la carpeta!';
$html_folders_updated = 'Carpetes anovaes';
$html_folder_subscribe = 'Suscribite a';
$html_folder_rename = 'Renomar';
$html_folder_create = 'Crear carpeta nueva llamada';
$html_folder_remove = 'De-suscribite de';
$html_folder_delete = 'Desaniciar';
$html_folder_to = 'a';
$html_filter_remove = 'Desaniciar';
$html_filter_body = 'Cuerpu del mensaxe';
$html_filter_subject = 'Asuntu del mensaxe';
$html_filter_to = 'Campu Pa';
$html_filter_cc = 'Campu CC';
$html_filter_from = 'Campu De';
$html_filter_change_tip = 'Para cambiar un filtru, simplemente sobreescríbilu.';
$html_reapply_filters = 'Re-aplicar tolos filtros';
$html_filter_contains = 'contién';
$html_filter_name = 'Nome del filtru';
$html_filter_action = 'Aición del filtru';
$html_filter_moveto = 'Mover a';
$html_select_one = '--Seleiciona unu--';
$html_and = 'Y';
$html_new_msg_in = 'Mensaxes nuevos en';
$html_or = 'o';
$html_move = 'Mover';
$html_copy = 'Copiar';
$html_messages_to = 'mensaxes seleicionaos a';
$html_gotopage = 'Dir a páxina';
$html_gotofolder = 'Dir a carpeta';
$html_other_folders = 'Llista de carpetes';
$html_page = 'Páxina';
$html_of = 'de';
$html_view_header = 'Ver testera';
$html_remove_header = 'Anubrir testera';
$html_inbox = 'Buzón';
$html_new_msg = 'Escribir';
$html_reply = 'Contestar';
$html_reply_short = 'Re:';
$html_reply_all = 'Responder a toos';
$html_forward = 'Reunviar';
$html_forward_short = 'Fwd:';
$html_forward_info = 'El mensaxe reunviáu mandaráse como axuntu a esti.';
$html_delete = 'Desaniciar';
$html_new = 'Nuevu';
$html_mark = 'Desaniciar';
$html_att_label = 'Axuntu:';
$html_atts_label = 'Axuntos:';
$html_unknown = '[desconocíu]';
$html_part_x = 'Parte %s';
$html_attach = 'Axuntar';
$html_attach_forget = '¡Tienes d\'axuntar el ficheru antes d\'unviar el mensaxe!';
$html_attach_delete = 'Desaniciar la esbilla';
$html_attach_none = '¡Tienes de seleicionar un ficheru a axuntar!';
$html_sort_by = 'Ordenar por';
$html_sort = 'Ordenar';
$html_from = 'De';
$html_from_label = 'De:';
$html_subject = 'Asuntu';
$html_subject_label = 'Asuntu:';
$html_date = 'Data';
$html_date_label = 'Data:';
$html_sent_label = 'Unviáu:';
$html_wrote = 'escribió';
$html_quote_wrote = 'El %1$s a les %2$s, %3$s escribió:';
$html_size = 'Tamañu';
$html_totalsize = 'Tamañu total';
$html_kb = 'kB';
$html_mb = 'MB';
$html_gb = 'GB';
$html_bytes = 'bytes';
$html_filename = 'Nome del ficheru';
$html_to = 'Pa';
$html_to_label = 'Pa:';
$html_cc = 'Cc';
$html_cc_label = 'Cc:';
$html_bcc_label = 'Cct:';
$html_nosubject = 'Sin asuntu';
$html_send = 'Unviar';
$html_cancel = 'Encaboxar';
$html_no_mail = 'Dengún mensaxe.';
$html_logout = 'Salir';
$html_msg = 'Mensaxe';
$html_msgs = 'Mensaxes';
$html_configuration = '¡Esti sirvidor nun ta bien configuráu!';
$html_priority = 'Prioridá';
$html_priority_label = 'Prioridá:';
$html_lowest = 'La menor';
$html_low = 'Baxa';
$html_normal = 'Normal';
$html_high = 'Alta';
$html_highest = 'La mayor';
$html_flagged = 'Marcáu';
$html_spam = 'Puxarra';
$html_spam_warning = 'Esti mensaxe clasificóse como puxarra.';
$html_receipt = 'Pidir una confirmación de llegada';
$html_select = 'Seleicionar';
$html_select_all = 'Invertir seleición';
$html_select_contacts = 'Seleicionar contautos';
$html_loading_image = 'Cargando la imaxe';
$html_send_confirmed = 'El corréu aceutóse pa entregalu';
$html_no_sendaction = 'Nun s\'especificó nenguna aición. Intente activar JavaScript.';
$html_error_occurred = 'Hebo un error';
$html_prefs_file_error = 'Nun pudo abrise\'l ficheru de preferencies pa escribir.';
$html_wrap = 'Númberu de caráuteres al qu\'axustar los mensaxes salientes:';
$html_wrap_none = 'Sin axuste';
$html_usenet_separator = 'Separador d\'Usenet ("-- \n") antes de la firma';
$html_mark_as = 'Marcar como';
$html_read = 'lleer';
$html_unread = 'por lleer';
$html_encoding_label = 'Codificación de caráuteres:';
$html_add = 'Amestar';
$html_contacts = 'Contautos de %1$s';
$html_modify = 'Camudar';
$html_back = 'Anterior';
$html_contact_add = 'Amestar un contactu nuevu';
$html_contact_mod = 'Editar un contactu';
$html_contact_first = 'Nome';
$html_contact_last = 'Apellíu';
$html_contact_nick = 'Alcuñu';
$html_contact_mail = 'Corréu';
$html_contact_list = 'Llista de contactos de %1$s';
$html_contact_del = 'de la llista de contactos';
$html_contact_count = '%1$d contactos';
$html_contact_err1 = 'El númberu máximu de contactos ye "%1$d"';
$html_contact_err2 = 'Nun pues amestar un contactu nuevu';
$html_contact_err3 = 'Nun tienes permisos d\'accesu a la llista de contactos';
$html_contact_none = 'Nun se pudo atopar nengún contactu.';
$html_del_msg = '¿Desaniciar los mensaxes esbillaos?';
$html_down_mail = 'Descargar';
$original_msg = '-- Mensaxe orixinal --';
$to_empty = '¡El campu "Pa" nun pue tar baleru!';
$html_images_warning = 'Pola to seguridá, nun s\'amuesen les imaxes remotes.';
$html_images_display = 'Amosar les imaxes';
$html_smtp_error_no_conn = 'Nun se pudo abrir la conexón SMTP';
$html_smtp_error_unexpected = 'Respuesta SMTP inesperada:';
$lang_could_not_connect = 'Nun se pudo coneutar col sirvidor';
$lang_invalid_msg_num = 'Númberu de mensaxes inválidu';
$html_file_upload_attack = 'Posible ataque de carga de ficheru';
$html_invalid_email_address = 'Direición de corréu inválida';
$html_invalid_msg_per_page = 'Númberu inválidu de mensaxes por páxina';
$html_invalid_wrap_msg = 'Anchu d\'axuste de mensaxe inválidu';
$html_seperate_msg_win = 'Mensaxes nuna ventana separada';
$html_err_file_contacts = 'Nun pudo abrise pa escritura el ficheru de contactos.';
$html_session_file_error = 'Nun pudo abrise pa escritura el ficheru de sesión.';
$html_login_not_allowed = 'Esti nome d\'aniciu de sesión nun tien permisu de conexón.';
$lang_err_send_delay = 'Tienes d\'aguardar ente dos correos (%1$d segundos)';
$html_search = 'Guetar';
$html_new_session = 'Sesión siguiente';
$html_fd_filename = 'Descargar %1$s';
$html_fd_mailcount = '{{PLURAL:$1|0=Nun hai mensaxes|1=Hai %1$d mensaxe|Hai %1$d mensaxes}} na carpeta.';
$html_fd_mailskip = 'Los mensaxes siguientes nun formarán parte del ficheru mbox porque pasaríen del memory_limit de php:';
$html_fd_filesize = 'tamañu %1$d';
$html_fd_skipcount = 'con %1$d correos';
$html_fd_largefolder = 'Dependiendo de la to velocidá de descarga, esta descarga pue fallar pol tiempu d\'espera del script.<br />Por favor, comprueba que la descarga tea completa o da-y a max_execution_time un valor más altu en php.ini.';
$reset_clicked = '¿Tas seguru de que quies llimpiar el formulariu?';
$html_send_recover = '¡Anicia sesión pa recuperar el borrador perdíu!';
$html_send_discard = 'Fai clic equí pa descartar el borrador guardáu.';

==> nocc-1.9.6.txz: usr/local/www/nocc/lang/ast.php <==
<?php
/**
 * Language configuration file for NOCC
 *
 * Copyright 2001 Nicolas Chalanset <nicocha@free.fr>
 * Copyright 2001 Olivier Cahagne <cahagn_o@epita.fr>
 *
 * This file is part of NOCC. NOCC is free software under the terms of the
 * GNU General Public License. You should have received a copy of the license
 * along with NOCC.  If not, see <http://www.gnu.org/licenses/>.
 *
 * @package    NOCC
 * @subpackage Translations
 * @license    http://www.gnu.org/licenses/ GNU General Public License
 * @version    SVN: $Id: $
 */
/** Asturian (asturianu)
 * 
 * See the qqq 'language' for message documentation incl. usage of parameters
 * To improve a translation please visit http://translatewiki.net
 *
 * @ingroup Language
 * @file
 *
 * @author Xuacu
 */

$default_date_format = '%d-%m-%Y';
$no_locale_date_format = '%d-%m-%Y';
$default_time_format = '%I:%M %p';
$err_user_empty = 'El campu usuariu ta baleru';
$err_passwd_empty = 'El campu contraseña ta baleru';
$alt_delete = 'Desaniciar los mensaxes esbillaos';
$alt_delete_one = 'Desaniciar el mensaxe';
$alt_new_msg = 'Mensaxes nuevos';
$alt_reply = 'Contestar al autor';
$alt_reply_all = 'Contestar a toos';
$alt_forward = 'Reunviar';
$alt_next = 'Siguiente';
$alt_prev = 'Anterior';
$title_next_page = 'Páxina siguiente';
$title_prev_page = 'Páxina anterior';
$title_next_msg = 'Siguiente mensaxe';
$title_prev_msg = 'Mensaxe anterior';
$html_theme_label = 'Tema:';
$html_welcome = 'Bienveníu a %1$s';
$html_login = 'Aniciar sesión';
$html_user_label = 'Usuariu:';
$html_passwd_label = 'Contraseña:';
$html_submit = 'Unviar';
$html_help = 'Ayuda';
$html_server_label = 'Sirvidor:';
$html_wrong = 'L\'usuariu o la contraseña son incorreutos';
$html_retry = 'Reintentar';
$html_remember = 'Recordame';
$html_lang_label = 'Llingua:';
$html_msgperpage_label = 'Mensaxes por páxina:';
$html_preferences = 'Preferencies';
$html_full_name_label = 'Nome completu:';
$html_email_address_label = 'Direición de corréu electrónicu:';
$html_bccself = 'Poneme na CCT';
$html_hide_addresses = 'Tapecer les direiciones';
$html_outlook_quoting = 'Citar al estilu Outlook';
$html_reply_to = 'Responder a';
$html_reply_to_label = 'Responder a:';
$html_use_signature = 'Usar robla';
$html_signature = 'Robla';
$html_signature_label = 'Robla:';
$html_reply_leadin_label = 'Prefixu de respuesta:';
$html_prefs_updated = 'Preferencies anovaes';
$html_manage_folders_link = 'Xestionar carpetes IMAP';
$html_manage_filters_link = 'Xestionar filtros de corréu';
$html_use_graphical_smilies = 'Usar emoticonos gráficos';
$html_sent_folder_label = 'Copiar los correos unviaos a una carpeta dedicada:';
$html_trash_folder_label = 'Mover los correos desaniciaos a una carpeta dedicada:';
$html_colored_quotes = 'Cites en colores';
$html_display_struct = 'Amosar testu estructuráu';
$html_send_html_mail = 'Unviar el corréu en formatu HTML';
$html_folders = 'Carpetes';
$html_folders_create_failed = '¡Nun pudo crease la carpeta!';
$html_folders_sub_failed = '¡Nun pudisti suscribite a la carpeta!';
$html_folders_unsub_failed = '¡Nun pudisti de-suscribite de la carpeta!';
$html_folders_rename_failed = '¡Nun pudo cambiase\'l nome de la carpeta!';
$html_folders_updated = 'Carpetes anovaes';
$html_folder_subscribe = 'Suscribite a';
$html_folder_rename = 'Renomar';
$html_folder_create = 'Crear carpeta nueva llamada';
$html_folder_remove = 'De-suscribite de';
$html_folder_delete = 'Desaniciar';
$html_folder_to = 'a';
$html_filter_remove = 'Desaniciar';
$html_filter_body = 'Cuerpu del mensaxe';
$html_filter_subject = 'Asuntu del mensaxe';
$html_filter_to = 'Campu Pa';
$html_filter_cc = 'Campu CC';
$html_filter_from = 'Campu De';
$html_filter_change_tip = 'Para cambiar un filtru, simplemente sobreescríbilu.';
$html_reapply_filters = 'Re-aplicar tolos filtros';
$html_filter_contains = 'contien';
$html_filter_name = 'Nome del filtru';
$html_filter_action = 'Aición del filtru';
$html_filter_moveto = 'Mover a';
$html_select_one = '--Seleiciona unu--';
$html_and = 'Y';
$html_new_msg_in = 'Mensaxes nuevos en';
$html_or = 'o';
$html_move = 'Mover';
$html_copy = 'Copiar';
$html_messages_to = 'mensaxes seleicionaos a';
$html_gotopage = 'Dir a páxina';
$html_gotofolder = 'Dir a carpeta';
$html_other_folders = 'Llista de carpetes';
$html_page = 'Páxina';
$html_of = 'de';
$html_view_header = 'Ver testera';
$html_remove_header = 'Anubrir testera';
$html_inbox = 'Buzón';
$html_new_msg = 'Escribir';
$html_reply = 'Contestar';
$html_reply_short = 'Re:';
$html_reply_all = 'Responder a toos';
$html_forward = 'Reunviar';
$html_forward_short = 'Fwd:';
$html_forward_info = 'El mensaxe reunviáu mandaráse como axuntu a esti.';
$html_delete = 'Desaniciar';
$html_new = 'Nuevu';
$html_mark = 'Desaniciar';
$html_att_label = 'Axuntu:';
$html_atts_label = 'Axuntos:';
$html_unknown = '[desconocíu]';
$html_part_x = 'Parte %s';
$html_attach = 'Axuntar';
$html_attach_forget = '¡Tienes d\'axuntar el ficheru antes d\'unviar el mensaxe!';
$html_attach_delete = 'Desaniciar la esbilla';
$html_attach_none = '¡Tienes de seleicionar un ficheru a axuntar!';
$html_sort_by = 'Ordenar por';
$html_sort = 'Ordenar';
$html_from = 'De';
$html_from_label = 'De:';
$html_subject = 'Asuntu';
$html_subject_label = 'Asuntu:';
$html_date = 'Data';
$html_date_label = 'Data:';
$html_sent_label = 'Unviáu:';
$html_wrote = 'escribió';
$html_quote_wrote = 'El %1$s a les %2$s, %3$s escribió:';
$html_size = 'Tamañu';
$html_totalsize = 'Tamañu total';
$html_kb = 'kB';
$html_mb = 'MB';
$html_gb = 'GB';
$html_bytes = 'bytes';
$html_filename = 'Nome del ficheru';
$html_to = 'Pa';
$html_to_label = 'Pa:';
$html_cc = 'Cc';
$html_cc_label = 'Cc:';
$html_bcc_label = 'Cct:';
$html_nosubject = 'Sin asuntu';
$html_send = 'Unviar';
$html_cancel = 'Encaboxar';
$html_no_mail = 'Dengún mensaxe.';
$html_logout = 'Salir';
$html_msg = 'Mensaxe';
$html_msgs = 'Mensaxes';
$html_configuration = '¡Esti sirvidor nun ta bien configuráu!';
$html_priority = 'Prioridá';
$html_priority_label = 'Prioridá:';
$html_lowest = 'La menor';
$html_low = 'Baxa';
$html_normal = 'Normal';
$html_high = 'Alta';
$html_highest = 'La mayor';
$html_flagged = 'Marcáu';
$html_spam = 'Puxarra';
$html_spam_warning = 'Esti mensaxe clasificóse como puxarra.';
$html_receipt = 'Pidir una confirmación de llegada';
$html_select = 'Seleicionar';
$html_select_all = 'Invertir seleición';
$html_select_contacts = 'Seleicionar contautos';
$html_loading_image = 'Cargando la imaxe';
$html_send_confirmed = 'El corréu aceutóse pa entregalu';
$html_no_sendaction = 'Nun s\'especificó nenguna aición. Intente activar JavaScript.';
$html_error_occurred = 'Hebo un error';
$html_prefs_file_error = 'Nun pudo abrise\'l ficheru de preferencies pa escribir.';
$html_wrap = 'Númberu de caráuteres al qu\'axustar los mensaxes salientes:';
$html_wrap_none = 'Sin axuste';
$html_usenet_separator = 'Separador d\'Usenet ("-- \n") antes de la firma';
$html_mark_as = 'Marcar como';
$html_read = 'lleer';
$html_unread = 'por lleer';
$html_encoding_label = 'Codificación de caráuteres:';
$html_add = 'Amestar';
$html_contacts = 'Contautos de %1$s';
$html_modify = 'Camudar';
$html_back = 'Anterior';
$html_contact_add = 'Amestar un contactu nuevu';
$html_contact_mod = 'Editar un contactu';
$html_contact_first = 'Nome';
$html_contact_last = 'Apellíu';
$html_contact_nick = 'Alcuñu';
$html_contact_mail = 'Corréu';
$html_contact_list = 'Llista de contactos de %1$s';
$html_contact_del = 'de la llista de contactos';
$html_contact_count = '%1$d contactos';
$html_contact_err1 = 'El númberu máximu de contactos ye "%1$d"';
$html_contact_err2 = 'Nun pues amestar un contactu nuevu';
$html_contact_err3 = 'Nun tienes permisos d\'accesu a la llista de contactos';
$html_contact_none = 'Nun se pudo atopar nengún contactu.';
$html_contact_ruler_top = 'Arriba';
$html_contact_listcheck_title = 'Marca p\'amestar el corréu a la llista.';
$html_contact_list_add = 'Amestar a la llista';
$html_contact_listname = 'Nome de la llista';
$html_contact_listonly = 'Sólo llistes';
$html_contact_all = 'Amosar too';
$html_contact_add_confirm = '¿Amestar correos a la llista esistente?';
$html_del_msg = '¿Desaniciar los mensaxes esbillaos?';
$html_down_mail = 'Descargar';
$original_msg = '-- Mensaxe orixinal --';
$to_empty = '¡El campu "Pa" nun pue tar baleru!';
$html_images_warning = 'Pola to seguridá, nun s\'amuesen les imaxes remotes.';
$html_images_display = 'Amosar les imaxes';
$html_smtp_error_no_conn = 'Nun se pudo abrir la conexón SMTP';
$html_smtp_error_unexpected = 'Respuesta SMTP inesperada:';
$lang_could_not_connect = 'Nun se pudo coneutar col sirvidor';
$lang_invalid_msg_num = 'Númberu de mensaxes inválidu';
$html_file_upload_attack = 'Posible ataque de carga de ficheru';
$html_invalid_email_address = 'Direición de corréu inválida';
$html_invalid_msg_per_page = 'Númberu inválidu de mensaxes por páxina';
$html_invalid_wrap_msg = 'Anchu d\'axuste de mensaxe inválidu';
$html_seperate_msg_win = 'Mensaxes nuna ventana separada';
$html_err_file_contacts = 'Nun pudo abrise pa escritura el ficheru de contactos.';
$html_session_file_error = 'Nun pudo abrise pa escritura el ficheru de sesión.';
$html_login_not_allowed = 'Esti nome d\'aniciu de sesión nun tien permisu de conexón.';
$lang_err_send_delay = 'Tienes d\'aguardar ente dos correos (%1$d segundos)';
$html_search = 'Guetar';
$html_new_session = 'Sesión siguiente';
$html_fd_filename = 'Descargar %1$s';
$html_fd_mailcount = '{{PLURAL:$1|0=Nun hai mensaxes|1=Hai %1$d mensaxe|Hai %1$d mensaxes}} na carpeta.';
$html_fd_mailskip = 'Los mensaxes siguientes nun formarán parte del ficheru mbox porque pasaríen del memory_limit de php:';
$html_fd_filesize = 'tamañu %1$d';
$html_fd_skipcount = 'con %1$d correos';
$html_fd_largefolder = 'Dependiendo de la to velocidá de descarga, esta descarga pue fallar pol tiempu d\'espera del script.<br />Por favor, comprueba que la descarga tea completa o da-y a max_execution_time un valor más altu en php.ini.';
$reset_clicked = '¿Tas seguru de que quies llimpiar el formulariu?';
$html_send_recover = '¡Anicia sesión pa recuperar el borrador perdíu!';
$html_send_discard = 'Fai clic equí pa descartar el borrador guardáu.';
$html_collect_label = 'Collechar automáticamente direiciones de corréu:';
$html_collect_option0 = 'Nunca';
$html_collect_option1 = 'Sólo de los correos salientes';
$html_collect_option2 = 'Sólo de los correos abiertos';
$html_collect_option3 = 'Siempre';
